Modules
Structs
- Loads EXR textures as Texture assets
- An error that occurs when loading a texture from a file.
- Loads HDR textures as Texture assets
- Loader for images that can be read by the
imagecrate. - Indicates to an
ImageLoaderhow anImageshould be sampled.
Enums
- Possible errors that can be produced by
ExrTextureLoader - How edges should be handled in texture addressing.
- Comparison function used for depth and stencil operations.
- Texel mixing mode when sampling between texels.
- Used in
Image, this determines what image sampler to use when rendering. The default setting,ImageSampler::Default, will read the sampler from theImagePluginat setup. Setting this toImageSampler::Descriptorwill override the global default descriptor for thisImage. - Color variation to use when the sampler addressing mode is
ImageAddressMode::ClampToBorder. - The type of a raw image buffer.
- Errors that occur while converting an
Imageinto aDynamicImage - An error that occurs when accessing specific pixels in a texture
- An error that occurs when loading a texture
Constants
Traits
- Extends the wgpu
TextureFormatwith information about the pixel. - Used to calculate the volume of an item.